<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-hu',
'0_langue' => 'Magyar [hu]',
'0_liste' => 'spip-hu@rezo.net',
'0_mainteneur' => 'trucy@freemail.huEcker G&aacute;bor (ecker.gabor@ecker.t-online.hu)',

// A
'access_interface_graphique' => 'Vissza a teljes grafikus fel&uuml;letre',
'access_mode_texte' => 'Egyszer&#369;s&iacute;tett sz&ouml;veges fel&uuml;let megjelen&iacute;t&eacute;se',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Cikk m&oacute;dos&iacute;t&aacute;sa',
'admin_modifier_auteur' => 'Szerz&#337; m&oacute;dos&iacute;t&aacute;sa',
'admin_modifier_breve' => 'H&iacute;r szerkeszt&eacute;se',
'admin_modifier_mot' => 'Kulcssz&oacute; m&oacute;dos&iacute;t&aacute;sa',
'admin_modifier_rubrique' => 'Rovat m&oacute;dos&iacute;t&aacute;sa',
'admin_recalculer' => 'Oldal friss&iacute;t&eacute;se',
'afficher_trad' => 'ford&iacute;t&aacute;sok megjelen&iacute;t&eacute;se',
'alerte_maj_impossible' => '<b>Hiba&nbsp;!</b> A SQL adatb&aacute;zis friss&iacute;t&eacute;se a @version@ verzi&oacute; fel&eacute; nem lehts&eacute;ges, tal&aacute;n adatb&aacute;zishoz val&oacute; m&oacute;dos&iacute;t&aacute;si jogosults&aacute;g miatt. Ilyenkor a t&aacute;rhely adminisztr&aacute;tor&aacute;hoz kell fordulni.',
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute; par ailleurs. La valeur actuelle est&nbsp;:', # MODIF
'analyse_xml' => 'XML elemz&eacute;s',
'annuler' => 'M&eacute;gsem',
'antispam_champ_vide' => 'K&eacute;rj&uuml;k, hagyja &uuml;resen ezt a mez&#337;t:',
'articles_recents' => 'Leg&uacute;jabb cikkek',
'avis_archive_incorrect' => 'Az archiv&aacute;l&aacute;si f&aacute;jl nem SPIP t&iacute;pus&uacute;',
'avis_archive_invalide' => 'Az archv&aacute;l&aacute;si f&aacute;jl &eacute;rv&eacute;nytelen',
'avis_attention' => 'Vigy&aacute;zat&nbsp;!',
'avis_champ_incorrect_type_objet' => '&Eacute;rv&eacute;nytelen mez&#337;n&eacute;v @name@ a(z) @type@ t&iacute;pus&uacute; objektumhoz',
'avis_colonne_inexistante' => 'A(z) @col@ nev&#369; oszlop nem l&eacute;tezik',
'avis_echec_syndication_01' => 'A szindik&aacute;l&aacute;s sikertelen: a kijel&ouml;lt backend nem dolgozhat&oacute; fel, vagy egyetlen cikket sem aj&aacute;nl fel.',
'avis_echec_syndication_02' => 'A szindik&aacute;l&aacute;s sikertelen: nem lehet el&eacute;rni a honlap backend-j&eacute;t.',
'avis_erreur' => 'Hiba: l&aacute;sd lejjebb',
'avis_erreur_connexion' => 'Csatlakoz&aacute;si hiba',
'avis_erreur_cookie' => 'Cookie hiba',
'avis_erreur_fonction_contexte' => 'Programoz&aacute;si hiba. Ezt a f&uuml;ggv&eacute;nyt nem lehet h&iacute;vni e k&ouml;r&uuml;lm&eacute;nyek k&ouml;z&ouml;tt.',
'avis_erreur_mysql' => 'SQL hiba',
'avis_erreur_sauvegarde' => 'Hiba a ment&eacute;s sor&aacute;n (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Probl&eacute;ma a priv&aacute;t z&oacute;n&aacute;ba l&eacute;p&eacute;skor',

// B
'barre_a_accent_grave' => 'Francia &eacute;kezetes A nagybet&#369; besz&uacute;r&aacute;sa',
'barre_aide' => 'Haszn&aacute;ljon a nyomdai jel&ouml;l&eacute;seket, hogy sz&eacute;p&iacute;tse az &iacute;r&aacute;sk&eacute;pet',
'barre_e_accent_aigu' => 'Francia &eacute;kezetes E nagybet&#369; besz&uacute;r&aacute;sa',
'barre_eo' => 'E bet&#369; besz&uacute;r&aacute;sa az O-ban',
'barre_eo_maj' => 'E bet&#369; besz&uacute;r&aacute;sa az O nagybet&#369;be',
'barre_euro' => 'Az &euro; karakter besz&uacute;r&aacute;sa',
'barre_gras' => '{{f&eacute;lk&ouml;v&eacute;r st&iacute;lus}} alkalmaz&aacute;sa',
'barre_guillemets' => '&laquo; idez&#337;jelekbe &raquo;',
'barre_guillemets_simples' => '&#147;id&eacute;z&#337;jelekbe&#148;',
'barre_intertitre' => '{{{k&ouml;zc&iacute;m st&iacute;lus}}} alkalmaz&aacute;sa',
'barre_italic' => '{d&#337;lt st&iacute;lus} alkalmaz&aacute;sa',
'barre_lien' => 'Hiperhivatkoz&aacute;s besz&uacute;r&aacute;sa [link sz&ouml;vege->http://...]',
'barre_lien_input' => 'K&eacute;rj&uuml;k, adja meg a hivatkoz&aacute;s c&eacute;lj&aacute;t. (Be&iacute;rhat egy webc&iacute;met http://www.mysite.com form&aacute;tumban, vagy egyszer&#369;en megadhatja az egyik cikk sz&aacute;m&aacute;t ezen az oldalon.)',
'barre_note' => '[[L&aacute;bjegyzet st&iacute;lus]] alkalmaz&aacute;sa',
'barre_paragraphe' => '&Uacute;j bekezd&eacute;s',
'barre_quote' => '<quote>&Uuml;zenet id&eacute;z&eacute;se</quote>',
'bouton_ajouter_document' => '&Uacute;J DOKUMENTUM', # MODIF
'bouton_ajouter_image' => '&Uacute;J K&Eacute;P', # MODIF
'bouton_ajouter_image_document' => 'Add an image or a document', # NEW
'bouton_changer' => 'M&oacute;dos&iacute;t&aacute;s',
'bouton_chercher' => 'Keres&eacute;s',
'bouton_choisir' => 'Kiv&aacute;laszt&aacute;s',
'bouton_download' => 'Download', # NEW
'bouton_enregistrer' => 'Ment&eacute;s',
'bouton_radio_desactiver_messagerie_interne' => 'Bels&#337; &uuml;zenetek letilt&aacute;sa',
'bouton_radio_envoi_annonces' => 'Szerkeszt&#337;i k&ouml;zlem&eacute;ny k&uuml;ld&eacute;se',
'bouton_radio_non_envoi_annonces' => 'Ne k&uuml;ldj&ouml;n k&ouml;zlem&eacute;nyeket',
'bouton_radio_non_envoi_liste_nouveautes' => 'Ne k&uuml;ldj&ouml;n list&aacute;t a leg&uacute;jabb h&iacute;rekr&#337;l',
'bouton_recharger_page' => 'az oldal &uacute;jrat&ouml;lt&eacute;se',
'bouton_telecharger' => 'Felt&ouml;lt&eacute;s',
'bouton_valider' => 'Rendben',

// C
'cal_apresmidi' => 'd&eacute;lut&aacute;n',
'cal_jour_entier' => 'eg&eacute;sz nap',
'cal_matin' => 'd&eacute;lel&#337;tt',
'cal_par_jour' => 'napi napt&aacute;r',
'cal_par_mois' => 'havi napt&aacute;r',
'cal_par_semaine' => 'heti napt&aacute;r',
'choix_couleur_interface' => 'sz&iacute;n',
'choix_interface' => 'v&aacute;lasztott interf&eacute;sz',
'colonne' => 'Oszlop',
'confirm_changer_statut' => 'Vigy&aacute;zat, az elem st&aacute;tusz&aacute;nak v&aacute;ltoztat&aacute;s&aacute;t k&eacute;rte. K&iacute;v&aacute;nja folytatni?',
'correcte' => 'helyes',

// D
'date_aujourdhui' => 'ma',
'date_avant_jc' => 'Kr.e.',
'date_dans' => '@delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'holnap',
'date_fmt_heures_minutes' => '@h@:@m@',
'date_fmt_jour_heure' => '@jour@ @heure@',
'date_fmt_jour_mois' => '@nommois@ @jour@',
'date_fmt_jour_mois_annee' => '@annee@. @nommois@ @jour@  ',
'date_fmt_mois_annee' => '@annee@. @nommois@',
'date_fmt_nomjour_date' => '@date@ @nomjour@',
'date_heures' => '&oacute;ra',
'date_hier' => 'tegnap',
'date_il_y_a' => 'ezel&#337;tt @delai@',
'date_jnum1' => '1.',
'date_jnum10' => '10.',
'date_jnum11' => '11.',
'date_jnum12' => '12.',
'date_jnum13' => '13.',
'date_jnum14' => '14.',
'date_jnum15' => '15.',
'date_jnum16' => '16.',
'date_jnum17' => '17.',
'date_jnum18' => '18.',
'date_jnum19' => '19.',
'date_jnum2' => '2.',
'date_jnum20' => '20.',
'date_jnum21' => '21.',
'date_jnum22' => '22.',
'date_jnum23' => '23.',
'date_jnum24' => '24.',
'date_jnum25' => '25.',
'date_jnum26' => '26.',
'date_jnum27' => '27.',
'date_jnum28' => '28.',
'date_jnum29' => '29.',
'date_jnum3' => '3.',
'date_jnum30' => '30.',
'date_jnum31' => '31.',
'date_jnum4' => '4.',
'date_jnum5' => '5.',
'date_jnum6' => '6.',
'date_jnum7' => '7.',
'date_jnum8' => '8.',
'date_jnum9' => '9.',
'date_jour_1' => 'Vas&aacute;rnap',
'date_jour_1_abbr' => 'Vas.',
'date_jour_1_initiale' => 'V.',
'date_jour_2' => 'H&eacute;tf&#337;',
'date_jour_2_abbr' => 'H&eacute;t.',
'date_jour_2_initiale' => 'H.',
'date_jour_3' => 'Kedd',
'date_jour_3_abbr' => 'Kedd',
'date_jour_3_initiale' => 'K.',
'date_jour_4' => 'Szerda',
'date_jour_4_abbr' => 'Sze.',
'date_jour_4_initiale' => 'Sz.',
'date_jour_5' => 'Cs&uuml;t&ouml;rt&ouml;k',
'date_jour_5_abbr' => 'Cs&uuml;t.',
'date_jour_5_initiale' => 'Cs.',
'date_jour_6' => 'P&eacute;ntek',
'date_jour_6_abbr' => 'P&eacute;nt.',
'date_jour_6_initiale' => 'P.',
'date_jour_7' => 'Szombat',
'date_jour_7_abbr' => 'Szo.',
'date_jour_7_initiale' => 'Sz.',
'date_jours' => 'nap',
'date_minutes' => 'perc',
'date_mois' => 'h&oacute;nap',
'date_mois_1' => 'janu&aacute;r',
'date_mois_10' => 'okt&oacute;ber',
'date_mois_11' => 'november',
'date_mois_12' => 'december',
'date_mois_2' => 'febru&aacute;r',
'date_mois_3' => 'm&aacute;rcius',
'date_mois_4' => '&aacute;prilis',
'date_mois_5' => 'm&aacute;jus',
'date_mois_6' => 'j&uacute;nius',
'date_mois_7' => 'j&uacute;lius',
'date_mois_8' => 'augusztus',
'date_mois_9' => 'szeptember',
'date_saison_1' => 't&eacute;l',
'date_saison_2' => 'tavasz',
'date_saison_3' => 'ny&aacute;r',
'date_saison_4' => '&#337;sz',
'date_secondes' => 'seconds', # NEW
'date_semaines' => 'h&eacute;t',
'date_un_mois' => 'month', # NEW
'date_une_heure' => 'hour', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'second', # NEW
'date_une_semaine' => 'week', # NEW
'dirs_commencer' => ' ahhoz, hogy val&oacute;ban kezdhesse a telep&iacute;t&eacute;st',
'dirs_preliminaire' => 'Bevezet&eacute;s: <b>Hozz&aacute;f&eacute;r&eacute;si jogok be&aacute;ll&iacute;t&aacute;sa</b>',
'dirs_probleme_droits' => 'Jogosults&aacute;gi hiba',
'dirs_repertoires_absents' => 'A k&ouml;vetkez&#337; mapp&aacute;k nem tal&aacute;lhat&oacute;k&nbsp;: <ul>@bad_dirs@.</ul> </b>
  <p>Ez val&oacute;sz&iacute;n&uuml;leg egy nagy-, kisbet&#369;s probl&eacute;ma.
  Ellen&#337;rizze, hogy a fenti mapp&aacute;k nagy-, &eacute;s kisbet&#369;i megfelelnek annak, ami feljebb megjelent
  ; ha m&eacute;gsem, FTP szoftver&eacute;vel nevezze &aacute;t a mapp&aacute;kat.
  </p><p>Ha megt&ouml;rt&eacute;nt ez a m&#369;velet, tudni fog</p>',
'dirs_repertoires_suivants' => '<b>A k&ouml;vetkez&#337; mapp&aacute;kra nincs &iacute;r&aacute;si jogosults&aacute;ga&nbsp;: <ul>@bad_dirs@.</ul> </b>
  <p>Annak jav&iacute;t&aacute;s&aacute;ra, haszn&aacute;lja az FTP kliens&eacute;t ahhoz, hogy be&aacute;ll&iacute;tsa minden mapp&aacute; hozz&aacute;f&eacute;r&eacute;si jogait
  Az elj&aacute;r&aacute;s r&eacute;szletesen van magyar&aacute;zva a telep&iacute;t&eacute;si k&eacute;zik&ouml;nyvben.
  </p><p>A megt&ouml;rt&eacute;nt ez a m&#369;velet, tudni fogja</p>', # MODIF
'double_occurrence' => 'K&eacute;t el&#337;fordul&aacute;s', # MODIF

// E
'en_cours' => 'processing', # NEW
'entree_dimensions' => 'M&eacute;ret&nbsp;:',
'entree_titre_document' => 'Dokumentum c&iacute;me&nbsp;:',
'entree_titre_image' => 'K&eacute;p c&iacute;me&nbsp;:',
'envoi_via_le_site' => 'K&uuml;ld&eacute;s a honlapon kereszt&uuml;l',
'erreur' => 'Hiba',
'erreur_balise_non_fermee' => 'az utols&oacute; tag nincs lez&aacute;rva:',
'erreur_texte' => 'hiba',
'etape' => 'Stage', # NEW

// F
'fichier_introuvable' => 'A(z) @fichier@ f&aacute;jl nem tal&aacute;lhat&oacute;',
'form_auteur_confirmation' => 'Please confirm your email address', # NEW
'form_auteur_email_modifie' => 'Your email address has been changed.', # NEW
'form_auteur_envoi_mail_confirmation' => 'A confirmation email has been sent to @email@. You need to visit the URL mentioned in this message in order to validate your email address.', # NEW
'form_auteur_mail_confirmation' => 'Hello,

You have asked to change your email address.
To confirm your new address, you need to connect to
the address below. (Otherwise your request will be ignored.):

    @url@
', # NEW
'form_deja_inscrit' => '&Ouml;n m&aacute;r regisztr&aacute;lt.',
'form_email_non_valide' => 'A megadott e-mail c&iacute;m &eacute;rv&eacute;nytelen.',
'form_forum_access_refuse' => '&Ouml;nnek m&aacute;r nincs hozz&aacute;f&eacute;r&eacute;se ehhez az oldalhoz.',
'form_forum_bonjour' => '&Uuml;dv&ouml;z&ouml;lj&uuml;k, @nom@,',
'form_forum_email_deja_enregistre' => 'Ez az email c&iacute;m m&aacute;r regisztr&aacute;lva van, teh&aacute;t haszn&aacute;lhatja a szok&aacute;sos jelszav&aacute;t.',
'form_forum_identifiant_mail' => '&Uacute;j azonos&iacute;t&oacute;j&aacute;t elk&uuml;ldt&uuml;k az e-mail c&iacute;m&eacute;re.',
'form_forum_identifiants' => 'Szem&eacute;lyes azonos&iacute;t&oacute;k',
'form_forum_indiquer_nom_email' => 'K&eacute;rj&uuml;k, adja meg nev&eacute;t &eacute;s e-mail c&iacute;m&eacute;t. A szem&eacute;lyes azonos&iacute;t&oacute;j&aacute;t e-mailben fogja megkapni.',
'form_forum_login' => 'Login:',
'form_forum_message_auto' => '(ez egy automatikus &uuml;zenet)',
'form_forum_pass' => 'jelsz&oacute;:',
'form_forum_probleme_mail' => 'E-mail probl&eacute;ma&nbsp;: az azonos&iacute;t&oacute; nem k&uuml;ldhet&#337; el.',
'form_forum_voici1' => 'Az azonos&iacute;t&oacute;ja, amivel r&eacute;szt vehet a(z) "@nom_site_spip@" (@adresse_site@) oldal &eacute;let&eacute;ben:',
'form_forum_voici2' => '&Iacute;me az azonos&iacute;t&oacute;i javasolt cikkek k&uuml;ld&eacute;s&eacute;hez a(z)
 "@nom_site_spip@" (@adresse_login@) oldalra:',
'form_indiquer_email' => 'K&eacute;rj&uuml;k, adja meg e-mail c&iacute;m&eacute;t.',
'form_indiquer_nom' => 'K&eacute;rj&uuml;k, adja meg a nev&eacute;t.',
'form_indiquer_nom_site' => 'K&eacute;rj&uuml;k, adja meg honlapj&aacute;nak c&iacute;m&eacute;t.',
'form_pet_adresse_site' => 'Honlapj&aacute;nak c&iacute;me',
'form_pet_aucune_signature' => 'Egyetlen al&aacute;&iacute;r&aacute;s sem felel meg ennek a k&oacute;dnak...',
'form_pet_confirmation' => 'K&eacute;rj&uuml;k, er&#337;s&iacute;tse meg al&aacute;&iacute;r&aacute;s&aacute;t:',
'form_pet_deja_enregistre' => 'Ezt a honlapot m&aacute;r regisztr&aacute;lt&aacute;k',
'form_pet_deja_signe' => 'M&aacute;r al&aacute;&iacute;rta ezt a sz&ouml;veget.',
'form_pet_envoi_mail_confirmation' => 'A meger&#337;s&iacute;t&#337; e-mailt elk&uuml;ldt&uuml;k. Al&aacute;&iacute;r&aacute;s&aacute;nak hiteles&iacute;t&eacute;s&eacute;hez l&aacute;togassa meg a benne tal&aacute;lhat&oacute; c&iacute;met.', # MODIF
'form_pet_mail_confirmation' => 'J&oacute; napot!

K&eacute;rte, hogy al&aacute;&iacute;rhassa ezt a petici&oacute;t:
@titre@.

A k&ouml;vetkez&#337; adatokat adta meg:
    N&eacute;v: @nom_email@
    Honlap: @nom_site@ - @url_site@
    @message@

FONTOS...
Az al&aacute;&iacute;r&aacute;s &eacute;rv&eacute;nyes&iacute;t&eacute;s&eacute;hez a
lenti c&iacute;mhez kell csatlakozni (ellenkez&#337; esetben az &Ouml;n k&eacute;r&eacute;se el lesz utas&iacute;tva) :

    @url@


K&ouml;sz&ouml;nj&uuml;k r&eacute;szv&eacute;tel&eacute;t!
',
'form_pet_message_commentaire' => '&Uuml;zenet, hozz&aacute;sz&oacute;l&aacute;s&nbsp;?',
'form_pet_nom_site2' => 'Honlapj&aacute;nak neve',
'form_pet_probleme_liens' => 'K&eacute;rj&uuml;k, t&ouml;r&ouml;lje a hiperhivatkoz&aacute;sokat &uuml;zenet&eacute;b&#337;l.',
'form_pet_probleme_technique' => 'Technikai hiba, az al&aacute;&iacute;r&aacute;s ideiglenesen fel van f&uuml;ggesztve.',
'form_pet_signature_pasprise' => 'Az &Ouml;n al&aacute;&iacute;r&aacute;sa nincs figyelembe v&eacute;ve.',
'form_pet_signature_validee' => 'Al&aacute;&iacute;r&aacute;s&aacute;t hiteles&iacute;tett&uuml;k. K&ouml;sz&ouml;nj&uuml;k&nbsp;!',
'form_pet_site_deja_enregistre' => 'Ezt a honlapot m&aacute;r regisztr&aacute;lt&aacute;k',
'form_pet_url_invalide' => 'A be&iacute;rt URL nem &eacute;rv&eacute;nyes.',
'form_pet_votre_email' => 'Az &Ouml;n email c&iacute;me',
'form_pet_votre_nom' => 'Az &Ouml;n neve vagy felhaszn&aacute;l&oacute;neve',
'form_pet_votre_site' => 'Amennyiben van saj&aacute;t honlapja, lejjebb jelezheti',
'form_prop_confirmer_envoi' => 'Er&#337;s&iacute;tse meg a k&uuml;ld&eacute;st',
'form_prop_description' => 'Le&iacute;r&aacute;s/hozz&aacute;sz&oacute;l&aacute;s',
'form_prop_enregistre' => 'A javaslat&aacute;t felvett&uuml;k. Nyilv&aacute;nosan akkor fog megjelenni, miut&aacute;n e honlap adminisztr&aacute;torai j&oacute;v&aacute;hagyt&aacute;k.',
'form_prop_envoyer' => '&Uuml;zenetk&uuml;ld&eacute;s',
'form_prop_indiquer_email' => 'K&eacute;rj&uuml;k, &eacute;rv&eacute;nyes e-mail c&iacute;met adjon meg',
'form_prop_indiquer_nom_site' => 'K&eacute;rj&uuml;k, adja meg a honlap nev&eacute;t.',
'form_prop_indiquer_sujet' => 'K&eacute;rj&uuml;k, adja meg a t&aacute;rgyat',
'form_prop_message_envoye' => '&Uuml;zenet elk&uuml;ldve',
'form_prop_nom_site' => 'Honlap neve',
'form_prop_non_enregistre' => 'A javaslat&aacute;t nem r&ouml;gz&iacute;tett&uuml;k.',
'form_prop_sujet' => 'T&aacute;rgy',
'form_prop_url_site' => 'Honlap c&iacute;me',
'forum_acces_refuse' => 'M&aacute;r nincs hozz&aacute;f&eacute;r&eacute;se ezekhez a f&oacute;rumokhoz.',
'forum_attention_dix_caracteres' => '<b>Vigy&aacute;zat&nbsp;!</b> Az &uuml;zenet&eacute;nek legal&aacute;bb 10 karaktert kell tartalmaznia.',
'forum_attention_trois_caracteres' => '<b>Vigy&aacute;zat&nbsp;!</b> A c&iacute;mnek legal&aacute;bb h&aacute;rom karaktert kell tartalmaznia.',
'forum_attention_trop_caracteres' => '<b>Figyelem&nbsp;!</b> az &uuml;zenete t&uacute;l hossz&uacute; (@compte@ karakter)&nbsp;: legfeljebb @max@ karakterb&#337;l &aacute;llhat.',
'forum_avez_selectionne' => 'Kijel&ouml;lt&nbsp;:',
'forum_cliquer_retour' => 'Kattintson <a href=\'@retour_forum@\'>ide</a> a folytat&aacute;shoz.',
'forum_forum' => 'f&oacute;rum',
'forum_info_modere' => 'Ez a f&oacute;rum el&#337;re moder&aacute;lt&nbsp;: az &Ouml;n hozz&aacute;sz&oacute;l&aacute;sa csak azut&aacute;n jelenik meg, hogy a honlap egyik adminisztr&aacute;tora j&oacute;v&aacute;hagyta.',
'forum_lien_hyper' => '<b>Hiperhivatkoz&aacute;s</b> (v&aacute;laszthat&oacute;)',
'forum_message_definitif' => 'V&eacute;gleges &uuml;zenet: k&uuml;ld&eacute;s a honlapra',
'forum_message_trop_long' => 'Az &Ouml;n &uuml;zenete t&uacute;l hossz&uacute;. A maxim&aacute;lis m&eacute;ret 20 000 karakter.',
'forum_ne_repondez_pas' => 'Ne erre az emailre v&aacute;laszoljon, hanem a f&oacute;rumon a k&ouml;vetkez&#337; c&iacute;men:',
'forum_non_inscrit' => 'Nincs regisztr&aacute;lva, vagy a c&iacute;m vagy a jelsz&oacute; hib&aacute;s.',
'forum_page_url' => '(Amennyiben az &Ouml;n &uuml;zenete egy interneten publik&aacute;lt, vagy tov&aacute;bbi inform&aacute;ci&oacute;t tartalmaz&oacute; oldalra vonatkozik, akkor adja meg az oldal nev&eacute;t, illetve URL c&iacute;m&eacute;t.)',
'forum_par_auteur' => '&Iacute;rta: @auteur@',
'forum_poste_par' => 'Az &uuml;zenetet @parauteur@ k&uuml;ldte, "@titre@" c&iacute;m&#369; cikk&eacute;re v&aacute;laszul.',
'forum_probleme_database' => 'Adatb&aacute;zis hiba, az &Ouml;n &uuml;zenet&eacute;t nem r&ouml;gz&iacute;tett&uuml;k.',
'forum_qui_etes_vous' => '<b>Kicsoda &Ouml;n?</b> (nem k&ouml;telez&#337;)',
'forum_texte' => '&Uuml;zenet&eacute;nek sz&ouml;vege:',
'forum_titre' => 'T&aacute;rgy:',
'forum_titre_erreur' => 'Hiba...',
'forum_url' => 'URL:',
'forum_valider' => '&Eacute;rv&eacute;nyes&iacute;tse v&aacute;laszt&aacute;s&aacute;t',
'forum_voir_avant' => 'K&uuml;ld&eacute;s el&#337;tti el&#337;n&eacute;zet megtekint&eacute;se',
'forum_votre_email' => 'Az &Ouml;n email c&iacute;me:',
'forum_votre_nom' => 'Az &Ouml;ne neve (vagy beceneve):',
'forum_vous_enregistrer' => 'A f&oacute;rum haszn&aacute;lat&aacute;hoz
  k&eacute;rj&uuml;k, el&#337;sz&ouml;r regisztr&aacute;ljon. Lentebb adja meg
  a szem&eacute;lyes azonos&iacute;t&oacute;t,
amit kapott. Amennyiben nincs regisztr&aacute;lva, akkor',
'forum_vous_inscrire' => 'regisztr&aacute;ljon.',

// I
'ical_texte_rss_articles' => 'A honlap cikkeinek &laquo;backend&raquo; f&aacute;jlja ezen a c&iacute;men tal&aacute;lhat&oacute;:',
'ical_texte_rss_articles2' => 'Egyar&aacute;nt lehet szerezni &laquo;backend&raquo; f&aacute;jlokat a honlap minden egyes rubrik&aacute;nak cikkeir&#337;l:',
'ical_texte_rss_breves' => 'R&aacute;ad&aacute;sul l&eacute;tezik olyan f&aacute;jl, ami a honlap h&iacute;reit tartalmazza. Egy rovatsz&aacute;m kijel&ouml;l&eacute;s&eacute;vel megkaphatja egyed&uuml;l annak a rovatnak a h&iacute;reit.',
'icone_a_suivre' => 'Ir&aacute;nyt&#369;',
'icone_admin_site' => 'Honlap adminisztr&aacute;l&aacute;sa',
'icone_agenda' => 'Napt&aacute;r',
'icone_aide_ligne' => 'S&uacute;g&oacute;',
'icone_articles' => 'Cikkek',
'icone_auteurs' => 'Szerz&#337;k',
'icone_breves' => 'H&iacute;rek',
'icone_brouteur' => 'Gyors b&ouml;ng&eacute;sz&eacute;s',
'icone_configuration_site' => 'Konfigur&aacute;l&aacute;s',
'icone_configurer_site' => 'A honlap konfigur&aacute;l&aacute;sa',
'icone_creer_nouvel_auteur' => '&Uacute;j szerz&#337; l&eacute;trehoz&aacute;sa',
'icone_creer_rubrique' => 'Rovat l&eacute;trehoz&aacute;sa',
'icone_creer_sous_rubrique' => 'Alrovat l&eacute;trehoz&aacute;sa',
'icone_deconnecter' => 'Kijelentkez&eacute;s',
'icone_discussions' => 'Vit&aacute;k',
'icone_doc_rubrique' => 'Mell&eacute;kelt dokumentumok',
'icone_ecrire_article' => '&Uacute;j cikk &iacute;r&aacute;sa',
'icone_edition_site' => 'Szerkeszt&eacute;s',
'icone_forum_administrateur' => 'Adminisztr&aacute;torok f&oacute;ruma',
'icone_forum_suivi' => 'F&oacute;rumok megfigyel&eacute;se',
'icone_gestion_langues' => 'Nyelvek kezel&eacute;se',
'icone_informations_personnelles' => 'Szem&eacute;lyes adatok',
'icone_interface_complet' => 'teljes fel&uuml;let',
'icone_interface_simple' => 'egyszer&#369;s&iacute;tett fel&uuml;let',
'icone_maintenance_site' => 'Honlap karbantart&aacute;sa',
'icone_messagerie_personnelle' => 'Szem&eacute;lyes levelez&eacute;s',
'icone_mots_cles' => 'Kulcsszavak',
'icone_nouvelle_breve' => '&Uacute;j h&iacute;r &iacute;r&aacute;sa',
'icone_repartition_actuelle' => 'Jelenlegi megoszt&aacute;s megjelen&iacute;t&eacute;se',
'icone_repartition_debut' => 'Kezdett&#337;l megjelen&iacute;teni a megoszt&aacute;st',
'icone_repartition_visites' => 'L&aacute;t&oacute;gat&aacute;sok sz&eacute;toszt&aacute;sa',
'icone_rubriques' => 'Rovatok',
'icone_sauver_site' => 'A honlap ment&eacute;se',
'icone_site_entier' => 'Az eg&eacute;sz honlap',
'icone_sites_references' => 'Felvett honlapok',
'icone_statistiques' => 'A honlap statisztikai',
'icone_statistiques_visites' => 'Statisztik&aacute;k',
'icone_suivi_activite' => 'A honlap &eacute;let&eacute;nek megfigyel&eacute;se',
'icone_suivi_actualite' => 'A honlap kialakul&aacute;sa',
'icone_suivi_forums' => 'Figyelni/kezelni a f&oacute;rumokat',
'icone_suivi_pettions' => 'Figyelni/kezelni az al&aacute;&iacute;r&aacute;sgy&#369;jt&eacute;seket',
'icone_suivi_revisions' => 'Cikkek m&oacute;dos&iacute;t&aacute;sa',
'icone_supprimer_document' => 'A dokumentum t&ouml;rl&eacute;se',
'icone_supprimer_image' => 'A k&eacute;p t&ouml;rl&eacute;se',
'icone_supprimer_message' => 'Az &uuml;zenet t&ouml;rl&eacute;se',
'icone_tous_articles' => 'Az &ouml;sszes cikkei',
'icone_tous_auteur' => 'Az &ouml;sszes szerz&#337;',
'icone_valider_message' => 'Az &uuml;zenet &eacute;rv&eacute;nyes&iacute;t&eacute;se',
'icone_visiter_site' => 'L&aacute;togat&aacute;s',
'icone_voir_en_ligne' => 'N&eacute;zni &eacute;l&#337;ben',
'image_tourner_180' => '180&deg; fordul&aacute;s',
'image_tourner_droite' => 'Fordul&aacute;s 90&deg; jobbra',
'image_tourner_gauche' => 'Fordul&aacute;s 90&deg; balra',
'img_indisponible' => 'hi&aacute;nyz&oacute; k&eacute;p',
'impossible' => 'nem lehets&eacute;ges',
'info_a_suivre' => 'FOLYTATNI&nbsp;&raquo;',
'info_a_valider' => '[&eacute;rv&eacute;nyes&iacute;tend&#337;]',
'info_acces_interdit' => 'Hozz&aacute;f&eacute;r&eacute;s tilos',
'info_acces_refuse' => 'Elutas&iacute;tott hozz&aacute;f&eacute;r&eacute;s',
'info_action' => 'M&#369;velet : @action@',
'info_administrer_rubriques' => 'Ezt a rovatot, illetve ennek alrovatait &Ouml;n adminisztr&aacute;lhatja',
'info_adresse_non_indiquee' => 'Nem jel&ouml;lt tesztelend&#337; c&iacute;met&nbsp;!',
'info_aide' => 'S&Uacute;G&Oacute; :',
'info_ajouter_mot' => 'A sz&oacute; hozz&aacute;ad&aacute;sa',
'info_annonce' => 'H&Iacute;RDET&Eacute;S',
'info_annonces_generales' => '&Aacute;ltal&aacute;nos h&iacute;rdet&eacute;sek&nbsp;:',
'info_article_propose' => 'Javasolt cikk',
'info_article_publie' => 'Publik&aacute;lt cikk',
'info_article_redaction' => 'Szerkezt&eacute;s alatti cikk',
'info_article_refuse' => 'Elutas&iacute;tott cikk',
'info_article_supprime' => 'T&ouml;r&ouml;lt cikk',
'info_articles' => 'Cikkek',
'info_articles_a_valider' => 'J&oacute;v&aacute;hagyand&oacute; cikkek',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Javasolt cikkek',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'szerz&#337;(k)&nbsp;:',
'info_authentification_ftp' => 'Autentifik&aacute;l&aacute;s (FTP-vel).',
'info_bloquer_lien' => 'blokkolni a linket',
'info_breves_02' => 'H&iacute;rek',
'info_breves_2' => 'h&iacute;rek',
'info_breves_nb' => '@nb@ news items', # NEW
'info_breves_un' => '1 news item', # NEW
'info_breves_valider' => 'J&oacute;v&aacute;hagyand&oacute; h&iacute;rek',
'info_connexion_refusee' => 'Csatlakoz&aacute;s tagadva',
'info_contact_developpeur' => 'Keressen egy fejleszt&#337;t.',
'info_contenance' => 'A honlap tartalmazza&nbsp;:',
'info_contribution' => 'F&oacute;rumi hozz&aacute;sz&oacute;l&aacute;sok',
'info_copyright' => '@spip@ egy szabad szoftver, let&ouml;lthet&#337;: @lien_gpl@.',
'info_copyright_doc' => 'B&#337;vebb inform&aacute;ci&oacute;kra, l&aacute;sd a honlapot <a href="@spipnet@">http://www.spip.net/fr</a>.', # MODIF
'info_copyright_gpl' => 'GPL licenz&uacute;',
'info_cours_edition' => 'Az &Ouml;n szerkeszt&eacute;s alatti cikkei',
'info_creer_repertoire' => 'Hozzon l&eacute;tre f&aacute;jlt, vagy mapp&aacute;t, melynek a neve&nbsp;:',
'info_creer_repertoire_2' => 'az almapp&aacute;n <b>@repertoire@</b> bel&uuml;l, ez&uacute;t&aacute;n&nbsp;:',
'info_creer_vignette' => 'a b&eacute;lyegk&eacute;p automatikus l&eacute;trehoz&aacute;sa',
'info_deplier' => 'Kibont&aacute;s',
'info_descriptif_nombre' => 'R&ouml;vid ismertet&#337;(k)&nbsp;:',
'info_description' => 'Le&iacute;r&aacute;s&nbsp;:',
'info_description_2' => 'Le&iacute;r&aacute;s&nbsp;:',
'info_dimension' => 'M&eacute;retek&nbsp;:',
'info_document' => 'Dokumentum',
'info_document_indisponible' => 'Ez a dokumentum nem &eacute;rhet&#337; el.',
'info_documents' => 'Dokumentumok',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP engedi a mag&aacute;n &uuml;zenetcser&eacute;t &eacute;s vitaf&oacute;rumok alak&iacute;t&aacute;s&aacute;t
  a honlap r&eacute;sztvev&#337;i k&ouml;z&ouml;tt. Ezt a lehet&#337;s&eacute;get lehet aktiv&aacute;lni, vagy inaktiv&aacute;lni.',
'info_ecire_message_prive' => 'Mag&aacute;n &uuml;zenet &iacute;r&aacute;sa',
'info_email_invalide' => '&Eacute;rv&eacute;nytelen email c&iacute;m.',
'info_en_cours_validation' => 'Az &Ouml;n szerkeszt&eacute;s alatti cikkei',
'info_en_ligne' => 'Jelenleg a vonalon&nbsp;:',
'info_envoyer_message_prive' => 'Szem&eacute;lyes &uuml;zenet k&uuml;ld&eacute;s ennek a szerz&#337;nek',
'info_erreur_requete' => 'Hiba a lek&eacute;rdez&eacute;sben :',
'info_erreur_squelette2' => 'Egyetlen csontv&aacute;z (template) <b>@fichier@</b> sem &aacute;ll rendelkez&eacute;sre...',
'info_erreur_systeme' => 'Rendszer hiba (errno @errsys@)',
'info_erreur_systeme2' => 'A merevlemez tal&aacute;n tele van, vagy megs&eacute;r&uuml;lt az adatb&aacute;zis. <br />
 <font color=\'red\'>prob&aacute;ljon <a href=\'@script@\'>jav&iacute;tani az adatb&aacute;zis</a>,
 vagy keresse fel a rendszergazd&aacute;t.</font>', # MODIF
'info_fini' => 'K&eacute;szen van !',
'info_format_image' => 'Haszn&aacute;lhat&oacute; k&eacute;pform&aacute;tumok a b&eacute;lyegk&eacute;pek k&eacute;sz&iacute;t&eacute;s&eacute;re&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'Hat&aacute;rozatlan form&aacute;tum',
'info_grand_ecran' => 'Nagy k&eacute;perny&#337;',
'info_image_aide' => 'S&Uacute;G&Oacute;',
'info_image_process_titre' => 'B&eacute;lyegk&eacute;pek k&eacute;sz&iacute;t&eacute;si m&oacute;dszer',
'info_impossible_lire_page' => '<b>Hiba !</b> Az opdal nem olvashat&oacute;  <tt><html>@test_proxy@</html></tt> a proxyn kereszt&uuml;l <tt>', # MODIF
'info_inclusion_directe' => 'K&ouml;zvetlen besz&uacute;r&aacute;s&nbsp;:',
'info_inclusion_vignette' => 'B&eacute;lyegk&eacute;p besz&uacute;r&aacute;sa&nbsp;:',
'info_installation_systeme_publication' => 'A publik&aacute;l&aacute;si rendszer telep&iacute;t&eacute;se...',
'info_installer_documents' => 'Automatikusan telep&iacute;theti az &ouml;sszes dokumentumot, amit tartalmaz az @upload@ nev&#369; mappa.',
'info_installer_ftp' => 'Mint adminisztr&aacute;tor, az @upload@ mapp&aacute;ba m&aacute;solhat (FTP-vel) f&aacute;jlokat, &eacute;s k&eacute;s&#337;bb k&ouml;zvetlen&uuml;l kijel&ouml;lheti &#337;ket itt.',
'info_installer_images' => 'JPEG, GIF &eacute;s PNG tipus&uacute; k&eacute;pek telep&iacute;thet&#337;k.',
'info_installer_images_dossier' => 'K&eacute;peket m&aacute;solni a @upload@ mapp&aacute;ba ahhoz, hogy itt lehessen kijel&ouml;lni.',
'info_installer_tous_documents' => 'Az &ouml;sszes dokumentum telep&iacute;t&eacute;se',
'info_interface_complete' => 'teljes fel&uuml;let',
'info_interface_simple' => 'Egyszer&#369;s&iacute;tett fel&uuml;let',
'info_joindre_document_article' => 'Olyan tipus&uacute; dokumentumokat csatolhat ehhez a cikkhez',
'info_joindre_document_rubrique' => 'Olyan tipus&uacute; dokumentumokat besz&uacute;rhat abba a rovatba',
'info_joindre_documents_article' => 'Olyan tipus&uacute; dokumentumok csatolhat&oacute;k az &Ouml;n cikk&eacute;hez&nbsp;:',
'info_l_article' => 'a cikk',
'info_la_breve' => 'a h&iacute;r',
'info_la_rubrique' => 'a rovat',
'info_langue_principale' => 'A honlap alapnyelve',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixel',
'info_les_auteurs_1' => '&iacute;rta @les_auteurs@',
'info_logo_format_interdit' => 'Csak a @formats@ tipus&uacute; formatumak vannak engedlyezve.',
'info_logo_max_poids' => 'Egy logo kisebb legyen, mint @maxi@ (ez a f&aacute;jl pedig @actuel@).',
'info_logo_max_taille' => 'Egy logo kisebb legyen, mint @maxi@ (ez a f&aacute;jl pedig @actuel@).',
'info_mail_fournisseur' => '&ouml;nmaga@szolgaltato.com',
'info_message_2' => '&Uuml;ZENET',
'info_message_supprime' => '&Uuml;ZENET T&Ouml;R&Ouml;LVE',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Publik&aacute;l&aacute;s id&#337;pontja&nbsp;:',
'info_modification_parametres_securite' => 'biztons&aacute;gi param&eacute;terek m&oacute;dos&iacute;t&aacute;sa',
'info_mois_courant' => 'A h&oacute;nap folyam&aacute;n :',
'info_mot_cle_ajoute' => 'A k&ouml;vetkez&#337; kulcssz&oacute; nem lett hozz&aacute;t&eacute;ve',
'info_multi_herit' => 'Alap&eacute;rtelmezett nyelv',
'info_multi_langues_soulignees' => 'Az <u>al&aacute;huzott nyelveknek</u> van ford&iacute;t&aacute;sa a fel&uuml;let &ouml;sszes sz&ouml;veg&eacute;re. Ha ezeket jel&ouml;li ki, akkor a nyilv&aacute;nos honlap sz&aacute;mos elemei (d&aacute;tumok, &#369;rlapok) lesznek automatikusan leford&iacute;tva. A nem al&aacute;h&uacute;zott nyelvekre pedig azok az elemek a honlap alapnyelv&eacute;n fognak megjelenni.', # MODIF
'info_multilinguisme' => 'T&ouml;bbnyelv&#369;s&eacute;g',
'info_nom_non_utilisateurs_connectes' => 'Az &Ouml;n neve nem szerepel a jelenleg csatlakozott felhaszn&aacute;l&oacute;k list&aacute;j&aacute;ban',
'info_nom_utilisateurs_connectes' => 'Az &Ouml;n neve szerepel a jelenleg csatlakozott felhaszn&aacute;l&oacute;k list&aacute;j&aacute;ban.',
'info_nombre_en_ligne' => 'Jelenleg a vonalon&nbsp;:',
'info_non_resultat' => 'Nincs tal&aacute;lat erre "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Nem haszn&aacute;lja a honlap bels&#337; levelez&eacute;s&eacute;t.',
'info_nouveau_message' => '&Ouml;NNEK &Uacute;J &Uuml;ZENETE VAN',
'info_nouveaux_messages' => '&Ouml;NNEK @total_messages@ &Uacute;J &Uuml;ZENETE VAN',
'info_numero_abbreviation' => 'sz.&nbsp;',
'info_obligatoire' => 'This information is required', # NEW
'info_panne_site_syndique' => 'Hib&aacute;s szindik&aacute;lt honlap',
'info_pense_bete' => 'EML&Eacute;KEZTET?',
'info_petit_ecran' => 'Kisebb k&eacute;perny?',
'info_petition_close' => 'K&eacute;relem lez&aacute;rva',
'info_pixels' => 'pixelek',
'info_plusieurs_mots_trouves' => 'N&eacute;hany kulcssz&oacute; tal&aacute;lt azzal "@cherche_mot@":',
'info_popularite_5' => 'n&eacute;pszer&#369;s&eacute;g&nbsp;:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'Automatikus portfolio&nbsp;:',
'info_premier_resultat' => '[@debut_limit@ els&#337; eredm&eacute;nyek, @total@ &ouml;sszesen]',
'info_premier_resultat_sur' => '[@debut_limit@ eredm&eacute;ny, &ouml;sszesen @total@]',
'info_probleme_grave' => 'probl&eacute;ma',
'info_propose_1' => '[@nom_site_spip@] ezt javasolta : @titre@',
'info_propose_2' => 'Javasolt cikk
---------------',
'info_propose_3' => 'A "@titre@" c&iacute;m&#369; cikket javasolt&aacute;k publik&aacute;l&aacute;sra.',
'info_propose_4' => 'K&eacute;rjuk, konzult&aacute;lja &eacute;s adjon r&oacute;la v&eacute;lem&eacute;ny&eacute;t',
'info_propose_5' => 'a hozz&aacute; kapcsol&oacute;d&oacute; f&oacute;rumban. El&eacute;rhet&#337; a k&ouml;vetkez&#337; c&iacute;men :',
'info_publie_01' => 'A "@titre@" c&iacute;m&#369; cikket @connect_nom@ hagyta j&oacute;v&aacute;.',
'info_publie_1' => '[@nom_site_spip@] PUBLIK&Aacute;LJA : @titre@',
'info_publie_2' => 'Publik&aacute;lt cikkek
--------------',
'info_rechercher' => 'Keres&eacute;s',
'info_rechercher_02' => 'Keres&eacute;s&nbsp;:',
'info_remplacer_vignette' => 'Az alap&eacute;rtelmezett b&eacute;lyegk&eacute;p helyettes&iacute;t&eacute;se egy szem&eacute;lyes logoval&nbsp;:',
'info_retablir_lien' => 'vissza&aacute;ll&iacute;tani ezt a linket',
'info_retirer_mot' => 'A sz&oacute; t&ouml;rl&eacute;se',
'info_retirer_mots' => 'Az &ouml;sszes sz&oacute; t&ouml;rl&eacute;se',
'info_rubriques_nb' => '@nb@ sections', # NEW
'info_rubriques_un' => '1 section', # NEW
'info_sans_titre_2' => 'c&iacute;m n&eacute;lk&uuml;l',
'info_selectionner_fichier' => 'Kijel&ouml;lhet egy f&aacute;jlt az @upload@ mapp&aacute;b&oacute;l',
'info_selectionner_fichier_2' => 'V&aacute;lasszon egy f&aacute;jlt&nbsp;:',
'info_signature_supprimee' => 'Al&aacute;&iacute;r&aacute;s t&ouml;r&ouml;lve',
'info_signature_supprimee_erreur' => 'Hiba: a t&ouml;rl&eacute;si k&oacute;d nem egyezik egyetlen al&aacute;&iacute;r&aacute;ssal sem',
'info_site_attente' => 'J&oacute;vahagy&aacute;s alatti honlap',
'info_site_reference' => 'Felvett honlap',
'info_site_refuse' => 'Elutas&iacute;tott honlap',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Honlap felv&eacute;tele',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'a b&eacute;lyegk&eacute;p t&ouml;rl&eacute;se',
'info_symbole_bleu' => 'A <b>k&eacute;k</b> jel <b>eml&eacute;keztet&#337;t</b> jelez: vagyis egy szem&eacute;lyes jelleg&#369; &uuml;zenetet.', # MODIF
'info_symbole_jaune' => 'A <b>s&aacute;rga</b> jel <b>minden szerz&#337;nek sz&oacute;l&oacute; h&iacute;rt</b> jelez&nbsp;: minden adminisztr&aacute;tor m&oacute;dos&iacute;thatja, &eacute;s minden szerz&#337; l&aacute;thatja.', # MODIF
'info_symbole_vert' => 'A <b>z&ouml;ld</b> jel a honlap <b>t&ouml;bbi felhaszn&aacute;l&oacute;ival cser&eacute;lt &uuml;zeneteket</b> jelzi.', # MODIF
'info_syndication' => 'szindik&aacute;l&aacute;s :',
'info_syndication_articles' => 'cikk(ek)',
'info_telecharger' => 'Felt&ouml;lt&eacute;s a g&eacute;p&eacute;r&#337;l&nbsp;:',
'info_telecharger_nouveau_logo' => '&Uacute;j logo felt&ouml;lt&eacute;se&nbsp;:',
'info_telecharger_ordinateur' => 'Felt&ouml;lt&eacute;s a g&eacute;p&eacute;r&#337;l&nbsp;:',
'info_tous_resultats_enregistres' => '[minden eredm&eacute;ny mentve]',
'info_tout_afficher' => 'Mindent megjelen&iacute;t',
'info_travaux_texte' => 'Ez a honlap m&eacute;g nincs konfigur&aacute;lva. J&ouml;jj&ouml;n vissza k&eacute;s&#337;bb...',
'info_travaux_titre' => 'A honlap jav&iacute;t&aacute;s alatt van',
'info_trop_resultat' => 'T&uacute;l sok eredm&eacute;ny erre "@cherche_mot@" ; Sz&uuml;k&iacute;tse a k&eacute;r&eacute;s&eacute;st.',
'info_utilisation_messagerie_interne' => 'A honlap bels&#337; levelez&#337;rendszer&eacute;t haszn&aacute;lhatja.',
'info_valider_lien' => 'a link j&oacute;v&aacute;hagy&aacute;sa',
'info_verifier_image' => ', elen&#337;rizze, hogy a k&eacute;pek megfelel&#337;en lettek m&aacute;solva.',
'info_vignette_defaut' => 'Alap&eacute;rtelmezett b&eacute;lyegk&eacute;p',
'info_vignette_personnalisee' => 'Szem&eacute;lyes b&eacute;lyegk&eacute;p',
'info_visite' => 'l&aacute;togat&aacute;s :',
'info_visites' => 'l&aacute;t&oacute;gat&aacute;s :',
'info_vos_rendez_vous' => 'A leend&#337; tal&aacute;lkoz&oacute;i',
'info_zoom' => 'nagy&iacute;t&aacute;s',
'infos_vos_pense_bete' => 'Az &Ouml;n eml&eacute;keztet&#337;i', # MODIF
'item_breve_proposee' => 'Javasolt h&iacute;r',

// L
'lien_afficher_icones_seuls' => 'Csak az ikonok megjelen&iacute;t&eacute;se',
'lien_afficher_texte_icones' => 'Ikonok &eacute;s sz&ouml;veg megjelen&iacute;t&eacute;se',
'lien_afficher_texte_seul' => 'Csak a sz&ouml;veg megjelen&iacute;t&eacute;se',
'lien_liberer' => 'szabad&iacute;tani',
'lien_liberer_tous' => 'a cikkek szabad&iacute;t&aacute;sa',
'lien_nouvea_pense_bete' => '&Uacute;J EML&Eacute;KEZTET&#336;',
'lien_nouveau_message' => '&Uacute;J &Uuml;ZENET',
'lien_nouvelle_annonce' => '&Uacute;J H&Iacute;RK&Ouml;ZL&Eacute;S',
'lien_petitions' => 'AL&Aacute;&Iacute;R&Aacute;SGY&#368;JT&Eacute;S',
'lien_popularite' => 'n&eacute;pszer&#369;s&eacute;g&nbsp;: @popularite@%',
'lien_racine_site' => 'HONLAP TETEJE',
'lien_reessayer' => '&uacute;jabb pr&oacute;ba',
'lien_repondre_message' => 'V&aacute;laszolni az &uuml;zenetre',
'lien_supprimer' => 't&ouml;r&ouml;l',
'lien_tout_afficher' => 'Mindent megjelen&iacute;t',
'lien_visite_site' => 'a honlap l&aacute;t&oacute;gat&aacute;sa',
'lien_visites' => '@visites@&nbsp;l&aacute;t&oacute;gat&aacute;s',
'lien_voir_auteur' => 'L&aacute;sd a szerz&#337;t',
'ligne' => 'Sor',
'login' => 'Kapcsolat',
'login_acces_prive' => 'Bel&eacute;p&eacute;s a priv&aacute;t r&eacute;szbe',
'login_autre_identifiant' => 'Csatlakoz&aacute;s m&aacute;sik azonos&iacute;t&oacute;val',
'login_cookie_accepte' => '&Aacute;ll&iacute;tsa be a b&ouml;ng&eacute;sz&#337;j&eacute;t &uacute;gy, hogy elfogadja &#337;ket(legal&aacute;bb ezen a honlapon).',
'login_cookie_oblige' => 'A honlaphoz val&oacute; biztons&aacute;gos azonos&iacute;t&aacute;s &eacute;rdek&eacute;ben a s&uuml;tiket (cookies) el kell fogadni.',
'login_deconnexion_ok' => 'Kijelentkez&eacute;s megt&ouml;rt&eacute;nt.',
'login_erreur_pass' => 'Hib&aacute;s jelsz&oacute;.',
'login_espace_prive' => 'priv&aacute;t r&eacute;sz',
'login_identifiant_inconnu' => 'A &laquo; @login@ &raquo; azonos&iacute;t&oacute; ismeretlen.',
'login_login' => 'Login :',
'login_login2' => 'Login (honlaphoz val&oacute; csatlakoz&aacute;si azonos&iacute;t&oacute;)&nbsp;:',
'login_login_pass_incorrect' => '(&Eacute;rv&eacute;nytelen login vagy jelsz&oacute;.)',
'login_motpasseoublie' => 'a&nbsp;jelsz&oacute;t&nbsp;elfelejtette&nbsp;?',
'login_non_securise' => 'Vigy&aacute;zat, az &#369;rlap nem biztons&aacute;gos.
   Ha nem akarja, hogy jelszav&aacute;t kaphass&aacute;k a h&aacute;lozaton, akkor a Javascriptet aktiv&aacute;lja
   a b&ouml;ng&eacute;sz&oacute;j&eacute;ben &eacute;s',
'login_nouvelle_tentative' => '&Uacute;jabb kis&eacute;rlet',
'login_par_ici' => 'Be van &iacute;ratkozva... errefel&eacute;...',
'login_pass2' => 'Jelsz&oacute;&nbsp;:',
'login_preferez_refuser' => '<b>Ha m&eacute;gis elutas&iacute;tja a s&uuml;tiket (cookies)</b>, akkor egy m&aacute;sik csatlakoz&aacute;si m&oacute;dszer (kev&eacute;sb&eacute; biztons&aacute;gos) &aacute;ll rendelkez&eacute;s&eacute;re&nbsp;:',
'login_recharger' => '&uacute;jra t&ouml;lteni az oldalt',
'login_rester_identifie' => 'Azonos&iacute;tva maradni p&aacute;r napig',
'login_retour_public' => 'Vissza a nyilv&aacute;nos honlapra',
'login_retour_site' => 'Vissza a nyilv&aacute;nos honlapra',
'login_retoursitepublic' => 'vissza&nbsp;a&nbsp;nyilv&aacute;nos&nbsp;honlapra',
'login_sans_cookiie' => 'S&uuml;ti (cookie) n&eacute;lk&uuml;li azonos&iacute;t&aacute;s',
'login_securise' => 'Secured login', # NEW
'login_sinscrire' => 'be&iacute;ratkoz&aacute;s',
'login_test_navigateur' => 'b&ouml;ng&eacute;sz&#337; teszt/&uacute;jracsatlakoz&aacute;s',
'login_verifiez_navigateur' => '(Azonban ellen&#337;rizze, hogy a bong&eacute;sz&oacute; nem memoriz&aacute;lta-e a jelsz&oacute;t...)',

// M
'masquer_colonne' => 'Oszlop elrejt&eacute;se',
'masquer_trad' => 'ford&iacute;t&aacute;sok elrejt&eacute;se',
'module_fichiers_langues' => 'Nyelvi f&aacute;jlok',

// N
'navigateur_pas_redirige' => 'Ha a b&ouml;ng&eacute;sz&oacute; nincsen &aacute;tir&aacute;ny&iacute;tva, akkor ide kattintson.',
'numero' => 'Sz&aacute;m',

// O
'occurence' => 'El&#337;fordul&aacute;s',
'onglet_affacer_base' => 'Adatb&aacute;zis t&ouml;rl&eacute;se',
'onglet_auteur' => 'A szerz&#337;',
'onglet_contenu_site' => 'A honlap tartalma',
'onglet_evolution_visite_mod' => 'Kialakul&aacute;s',
'onglet_fonctions_avances' => 'B&#337;v&iacute;tett funkci&oacute;k',
'onglet_informations_personnelles' => 'Szem&eacute;lyes adatok',
'onglet_interactivite' => 'Interaktivit&aacute;s',
'onglet_messagerie' => 'Levelez&eacute;s',
'onglet_messages_internes' => 'Bels&#337; &uuml;zenetek',
'onglet_messages_publics' => 'Nyilv&aacute;nos &uuml;zenetek',
'onglet_messages_vide' => 'Sz&ouml;veg n&eacute;lk&uuml;li &uuml;zenetek',
'onglet_origine_visites' => 'A l&aacute;t&oacute;gat&aacute;sok sz&aacute;rmaz&aacute;sa',
'onglet_repartition_debut' => 'kezdett&#337;l',
'onglet_repartition_lang' => 'Nyelvek szerinti bont&aacute;s',
'onglet_repartition_rubrique' => 'Rovat szerinti bont&aacute;s',
'onglet_save_restaur_base' => 'Adatb&aacute;zis ment&eacute;se/resztaur&aacute;l&aacute;sa',
'onglet_vider_cache' => 'Cache &uuml;r&iacute;t&eacute;se',
'ortho_trop_de_fautes2' => 'El&ouml;sz&#337;r jav&iacute;tsa a legegy&eacute;rtelm&#369;bb hib&aacute;kat, majd prob&aacute;lkozzon &uacute;jra.',

// P
'pass_choix_pass' => 'Legyen sz&iacute;ves v&aacute;lasztani az &uacute;j jelszav&aacute;t :',
'pass_erreur' => 'Hiba',
'pass_erreur_acces_refuse' => '<b>Hiba :</b> m&aacute;r nincs hozz&aacute;f&eacute;r&eacute;se arra a honlapra.',
'pass_erreur_code_inconnu' => '<b>Hiba :</b> ez a k&oacute;d a honlap egyik enged&eacute;lyezett felhaszn&aacute;l&oacute;janak sem felel meg.',
'pass_erreur_non_enregistre' => '<b>Hiba :</b> a c&iacute;m <tt>@email_oubli@</tt> nincs felv&eacute;ve ezen a honlapon.',
'pass_erreur_non_valide' => '<b>Hiba :</b> ez az email <tt>@email_oubli@</tt> &eacute;rv&eacute;nytelen !',
'pass_erreur_probleme_technique' => '<b>Hiba :</b> m&#369;szaki okb&oacute;l, az email nem k&uuml;ldhet&#337; el.',
'pass_espace_prive_bla' => 'A priv&aacute;t r&eacute;sz ny&iacute;tott a
  l&aacute;t&oacute;gat&oacute;k r&eacute;sz&eacute;re, miut&aacute;n be&iacute;ratkoztak. Ha be van iratkozva,
 akkor megtekintheti a szerkeszt&eacute;s alatti cikkeket,
 javasolhat cikkeket &eacute;s r&eacute;szt vehet a f&oacute;rumokban.',
'pass_forum_bla' => 'Hozz&aacute;sz&oacute;l&aacute;st k&eacute;rt olyan f&oacute;rumon, ami a beiratkozott l&aacute;t&oacute;gat&oacute;knak van fenntartva.',
'pass_indiquez_cidessous' => 'Lejjebb jelezze az email c&iacute;met, amivel be&iacute;ratkozott az im&eacute;nt. Olyan
   emailt fog kapni, ami mutatja az elj&aacute;r&aacute;st az &Ouml;n hozz&aacute;f&eacute;r&eacute;s&eacute;nek visszaszerz&eacute;s&eacute;re.',
'pass_mail_passcookie' => '(Ez egy automatikus &uuml;zenet)
A @nom_site_spip@ (@adresse_site@)
honlaphozz&aacute;f&eacute;r&eacute;s visszaszerz&eacute;s&eacute;re
Menjen a k&ouml;vetkez&#337; c&iacute;mre :

    @sendcookie@

Akkor &uacute;jabb jelsz&oacute;t tud be&iacute;rni
&eacute;s &uacute;jra csatlakozhat a honlapra.

',
'pass_mot_oublie' => 'Elfelejtett jelsz&oacute;',
'pass_nouveau_enregistre' => 'Az &uacute;j jelszava fel lett v&eacute;ve.',
'pass_nouveau_pass' => '&Uacute;j jelsz&oacute;',
'pass_ok' => 'Rendben',
'pass_oubli_mot' => 'Jelsz&oacute; elveszt&eacute;se',
'pass_quitter_fenetre' => 'Kil&eacute;pni az ablakb&oacute;l',
'pass_rappel_login' => 'Eml&eacute;keztet&#337; : az &Ouml;n azonos&iacute;t&oacute;ja (login) &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Hamarosan olyan emailt fog kapni, ami mutatja hogyan lehet visszaszerezni a hozz&aacute;f&eacute;r&eacute;st a honlapra.',
'pass_retour_public' => 'Vissza a nyilv&aacute;nos honlapra',
'pass_rien_a_faire_ici' => 'Nincs keresnival&oacute;ja itt.',
'pass_vousinscrire' => 'Be&iacute;ratkoz&aacute;s ezen a honlapon',
'precedent' => 'el&ouml;z&#337;',
'previsualisation' => 'El&#337;n&eacute;zet',
'previsualiser' => 'El&#337;n&eacute;zet',

// R
'retour' => 'Vissza',

// S
'spip_conforme_dtd' => 'A SPIP szerint ez az oldal teljes&iacute;ti a DOCTYPE k&ouml;vetelm&eacute;nyeit:',
'squelette' => 'v&aacute;zlat',
'squelette_inclus_ligne' => 'v&aacute;zlatot bele&eacute;rtve, sor',
'squelette_ligne' => 'v&aacute;zlat, sor',
'stats_visites_et_popularite' => '@visites@ l&aacute;togat&aacute;s&nbsp;; n&eacute;pszer&#369;s&eacute;g&nbsp;: @popularite@',
'suivant' => 'k&ouml;vetkez&#337;',

// T
'taille_ko' => '@taille@&nbsp;ko',
'taille_mo' => '@taille@&nbsp;Mo',
'taille_octets' => '@taille@&nbsp;byte',
'texte_actualite_site_1' => 'Ha bar&aacute;tkozik a fel&uuml;lettel akkor kattintson arra &laquo;',
'texte_actualite_site_2' => 'teljes fel&uuml;let',
'texte_actualite_site_3' => '&raquo; t&ouml;bb lehet&#337;s&eacute;g megny&iacute;t&aacute;s&aacute;ra.',
'texte_creation_automatique_vignette' => 'A b&eacute;lyegk&eacute;pek automatikus l&eacute;trehoz&aacute;sa aktiv&aacute;lva van a honlapon. Ha err&#337;l az &#369;rlapr&oacute;l telep&iacute;t @gd_formats@ form&aacute;tum&uacute; k&eacute;peket, akkor majd b&eacute;lyegk&eacute;p kis&eacute;ri, melynek maxim&aacute;lis m&eacute;rete @taille_preview@&nbsp;pixel.',
'texte_documents_associes' => 'A k&ouml;vetkez&#337; dokumentumok tartoznak a cikk,
    de nem lettek k&ouml;zvetlen&uuml;l
   besz&uacute;rva. A nyilv&aacute;nos r&eacute;sz oldalbe&aacute;ll&iacute;t&aacute;sa szerint,
  csatolt dokumentumok form&aacute;ban jelenhetnek meg.',
'texte_erreur_mise_niveau_base' => 'Adatb&aacute;zis hiba verzi&oacute;friss&iacute;t&eacute;skor.
  A <b>@fichier@</b> k&eacute;p nem ment &aacute;t (@id_article@ cikk).
 Jegyezze meg ezt a nevet, pr&oacute;bl&aacute;ja &uacute;jra a friss&iacute;t&eacute;st, &eacute;s v&eacute;g&uuml;l ellen&#337;rizze, hogy a k&eacute;pek mindig jelennek meg a cikkekben.', # MODIF
'texte_erreur_visiteur' => 'Olyan azonos&iacute;t&oacute;val pr&oacute;b&aacute;lt hozz&aacute;f&eacute;rni a priv&aacute;t z&oacute;n&aacute;hoz, aminek ehhez nincs jogosults&aacute;ga.',
'texte_inc_auth_1' => '&Ouml;n a <b>@auth_login@</b> loginnal
van azonos&iacute;tva, nem ez l&eacute;tezik/l&eacute;tezett az adatb&aacute;zisban. 
Pr&oacute;b&aacute;ljon', # MODIF
'texte_inc_auth_2' => '&uacute;jra csatlakozni',
'texte_inc_auth_3' => ', miut&aacute;n esetleg bez&aacute;rta &eacute;s 
&uacute;jraind&iacute;totta a b&ouml;ng&eacute;sz&#337;j&eacute;t.',
'texte_inc_config' => 'Az ezeken az oldalokon v&eacute;gzett m&oacute;dos&iacute;t&aacute;sok jelent&#337;sen befoly&aacute;solj&aacute;k a
 honlap m&#369;k&ouml;d&eacute;s&eacute;t. Javasoljuk, hogy ne  avatkozzon bele, amig &Ouml;n nem j&aacute;r&aacute;tos
 az SPIP m&#369;k&ouml;d&eacute;s&eacute;ben. <br /><br /><b>&Aacute;ltal&aacute;ban nagyon tan&aacute;csos b&iacute;zni ezeket az oldalakat
 a honlap f&#337; webmester&eacute;re.</b>', # MODIF
'texte_inc_meta_1' => 'A rendszer hib&aacute;t &eacute;szlelt a <code>@fichier@</code> f&aacute;jl &iacute;r&aacute;s&aacute;kor. Mint honlap adminisztr&aacute;tor, legyen sz&iacute;ves',
'texte_inc_meta_2' => 'ellen&#337;rizni a ir&aacute;si jogokat',
'texte_inc_meta_3' => 'a <code>@repertoire@</code> nev&#369; mapp&aacute;n.',
'texte_statut_en_cours_redaction' => 'szerkeszt&eacute;s alatt',
'texte_statut_poubelle' => 'szemetesbe',
'texte_statut_propose_evaluation' => 'felm&eacute;r&eacute;sre javasolt',
'texte_statut_publie' => 'publik&aacute;lt',
'texte_statut_refuse' => 'elutas&iacute;tott',
'titre_ajouter_mot_cle' => 'KULCSSZ&Oacute; HOZZ&Aacute;AD&Aacute;S :',
'titre_breve_proposee' => 'Javasolt h&iacute;r',
'titre_breve_publiee' => 'Publik&aacute;lt h&iacute;r',
'titre_breve_refusee' => 'Elutas&iacute;tott h&iacute;r',
'titre_cadre_raccourcis' => 'GYORS HIVATKOZ&Aacute;SOK :',
'titre_changer_couleur_interface' => 'Fel&uuml;let sz&iacute;ne v&aacute;ltoztat&aacute;sa',
'titre_forum' => 'F&oacute;rum',
'titre_image_admin_article' => 'Ezt a cikket &Ouml;n adminisztr&aacute;lhatja',
'titre_image_administrateur' => 'Adminisztr&aacute;tor',
'titre_image_aide' => 'S&uacute;g&oacute; err&#337;l a r&eacute;szr&#337;l',
'titre_image_auteur_supprime' => 'Szerz&#337; t&ouml;r&ouml;lve',
'titre_image_redacteur' => 'Hozz&aacute;f&eacute;r&eacute;s n&eacute;lk&uuml;li szerz&#337;',
'titre_image_redacteur_02' => 'Szerz&#337;',
'titre_image_visiteur' => 'Vend&eacute;g',
'titre_joindre_document' => 'DOKUMENTUM CSATOL&Aacute;SA',
'titre_liens_entrants' => 'Bej&ouml;v&#337; linkek',
'titre_mots_cles' => 'KULCSSZAVAK',
'titre_probleme_technique' => 'Vigy&aacute;zat&nbsp;: m&#369;szaki hiba (SQL szerver) miatt nincs hozz&aacute;f&eacute;r&eacute;s erre a r&eacute;szre. Meg&eacute;rt&eacute;s&eacute;t k&ouml;sz&ouml;nj&uuml;k.', # MODIF
'titre_publier_document' => 'DOKUMENTUM PUBLIK&Aacute;L&Aacute;SA ABBAN A ROVATBAN',
'titre_signatures_attente' => '&Eacute;rv&eacute;nyes&iacute;t&eacute;sre v&aacute;rakoz&oacute; al&aacute;&iacute;r&aacute;sok',
'titre_signatures_confirmees' => '&Eacute;rv&eacute;nyes&iacute;tett al&aacute;&iacute;r&aacute;sok',
'titre_statistiques' => 'A honlap statisztikai',
'titre_titre_document' => 'Dokumentum c&iacute;me&nbsp;:',
'todo' => 'to come', # NEW
'trad_reference' => '(eredeti cikk)',

// Z
'zbug_balise_b_aval' => '&nbsp;: B jelz&#337; ut&aacute;n',
'zbug_balise_inexistante' => 'hiba @from@: a(z) #@balise@ tag nem l&eacute;tezik', # MODIF
'zbug_balise_sans_argument' => 'Hi&aacute;nyz&oacute; argumentum a(z) @balise@ tagban',
'zbug_boucle' => 'folyamat',
'zbug_boucle_recursive_undef' => 'hat&aacute;rozatlan rekurz&iacute;v folyamat', # MODIF
'zbug_calcul' => 'sz&aacute;mol&aacute;s',
'zbug_champ_hors_boucle' => 'A @champ@ mez&#337; a folyamaton k&iacute;v&uuml;l van',
'zbug_champ_hors_motif' => 'A @champ@ mez&#337; egy @motif@ jelleg&#369; folyamaton k&iacute;v&uuml;l van', # MODIF
'zbug_code' => 'k&oacute;d',
'zbug_critere_inconnu' => 'ismeretlen krit&eacute;rium @critere@', # MODIF
'zbug_distant_interdit' => 'k&uuml;ls&#337; tilos', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'duplumokat haszn&aacute;lt egy t&aacute;bl&aacute;n, amin nincs egyszer&#369; els&#337;dleges kulcs', # MODIF
'zbug_doublon_table_sans_index' => 'index n&eacute;lk&uuml;li duplumok egy t&aacute;bl&aacute;ban', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: dupla definici&oacute;', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: z&aacute;r&oacute; tag hi&aacute;nyzik', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Folyamat szint&aacute;xisa nem korrekt', # MODIF
'zbug_erreur_compilation' => '&Ouml;ssze&aacute;ll&iacute;t&aacute;si hiba',
'zbug_erreur_execution_page' => 'futtat&aacute;si hiba az oldaln&aacute;l', # MODIF
'zbug_erreur_filtre' => 'Hiba : sz&#369;r&#337; <b>&laquo; @filtre@ &raquo;</b> nincs meghat&aacute;rozva', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} csak a (FORUMS) vagy (RUBRIQUES) folyamatokn&aacute;l alkalmazhat&oacute;', # MODIF
'zbug_erreur_squelette' => 'Hiba a v&aacute;zban',
'zbug_hors_compilation' => 'Nincs &ouml;ssze&aacute;ll&iacute;tva',
'zbug_info_erreur_squelette' => 'Hiba a honlapon',
'zbug_inversion_ordre_inexistant' => 'nem l&eacute;tez&#337; sorrend megford&iacute;t&aacute;sa', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION tag {pagination} krit&eacute;rium n&eacute;lk&uuml;l, vagy rekurz&iacute;v ism&eacute;tl&eacute;sben haszn&aacute;lta', # MODIF
'zbug_parametres_inclus_incorrects' => 'Hib&aacute;s inkluzi&oacute;s parameterek', # MODIF
'zbug_profile' => 'Sz&aacute;mol&aacute;s hossza: @time@',
'zbug_resultat' => 'eredm&eacute;ny',
'zbug_serveur_indefini' => 'hat&aacute;rozatlan SQL szerver', # MODIF
'zbug_statistiques' => 'SQL k&eacute;r&eacute;sek statisztik&aacute;ja hossz szerint',
'zbug_table_inconnue' => 'A &laquo; @table@ &raquo; nev&#369; SQL t&aacute;bla ismeretlen',
'zxml_connus_attributs' => 'ismert tulajdons&aacute;gok',
'zxml_de' => 'Innen:',
'zxml_inconnu_attribut' => 'ismeretlen tulajdons&aacute;g',
'zxml_inconnu_balise' => 'ismeretlen tag',
'zxml_inconnu_entite' => 'ismeretlen bejegyz&eacute;s',
'zxml_inconnu_id' => 'ismeretlen ID',
'zxml_mais_de' => 'de innen:',
'zxml_non_conforme' => 'nem &eacute;rv&eacute;nyes az alapelvre',
'zxml_non_fils' => 'nem a gyermeke neki:',
'zxml_nonvide_balise' => 'a tag nem &uuml;res',
'zxml_obligatoire_attribut' => 'sz&uuml;ks&eacute;ges tulajdons&aacute;g hi&aacute;nyzik ebben:',
'zxml_succession_fils_incorrecte' => 'hib&aacute;s &ouml;r&ouml;kl&eacute;s',
'zxml_survoler' => 'a helyesek megjelen&iacute;t&eacute;s&eacute;hez mozgassa f&ouml;l&eacute;j&uuml;k az egeret',
'zxml_valeur_attribut' => 'tulajdons&aacute;g &eacute;rt&eacute;ke',
'zxml_vide_balise' => '&uuml;res tag',
'zxml_vu' => 'l&aacute;tva ezel&#337;tt:'
);

?>
